@@ -30,12 +30,14 @@
  * GPL.
  */
 
-#include <iostream.h>
+//#include <iostream.h>
 #include <assert.h>
 #include "error.h"
 //#include "base.h"
 //#include "proc.h"
 
+// GP: clean
+
 SabMsg SablotMessages[] = 
 {
     {E_OK, "OK"},
@@ -79,7 +81,7 @@ SabMsg SablotMessages[] =
     {ET_VARIABLE_NOT_FOUND, "variable not found"}, 
     {ET_XSL_SYNTAX, "XSLT syntax error"}, 
     {ET_BAD_PREFIX, "invalid namespace prefix '%s'"}, 
-    {ET_DUPLICATE_RULE_NAME, "duplicate rule name '%s'"}, 
+    {ET_DUPLICATE_RULE_NAME, "duplicit rule name '%s'"}, 
     {ET_RULE_NOT_FOUND, "called nonexistent rule"}, 
     {ET_CONTEXT_FOR_BAD_EXPR, "expression is not a node set"}, 
     {ET_FUNC_NOT_SUPPORTED, "function '%s' not supported"}, 
@@ -112,6 +114,8 @@ SabMsg SablotMessages[] =
     {E_ELEM_IN_COMMENT_PI, "element created inside a comment or processing instruction"},
     {E1_INVALID_HLR_TYPE, "invalid handler type '%s'"},
     {E1_XSL_MESSAGE_TERM, "xsl:message (%s) - terminating"},
+    {E1_UNKNOWN_ENC, "unknown encoding '%s'"},
+    {E1_BAD_CHAR, "bad character for encoding '%s'"},
     {E_NONE, ""},
     {W_UNSUPP_LANG, "function lang() not supported, returning false"},
     {W_NO_STYLESHEET, "the included or imported stylesheet '%s' contains "\
@@ -132,6 +136,7 @@ SabMsg SablotMessages[] =
     {W1_SORT_CASE_ORDER, "invalid case order '%s', using default"},
     {W1_LANG, "unsupported language '%s'"},
     {W_NO_WCSXFRM, "international sorting unavailable on this system - sorting naively"},
+    {W_BAD_START, "document starts with unrecognized sequence"},
     {W_NONE, ""},
     {L_START, "\n--------starting processing: %s"},
     {L1_PARSING, "Parsing '%s'..."},
