@@ -17,6 +17,7 @@
  * 
  * Contributor(s):
  *      Bob Jenkins <bob_jenkins@burtleburtle.net>
+ *      Tom Moog <tmoog@polhode.com>
  * 
  * Alternatively, the contents of this file may be used under the
  * terms of the GNU General Public License Version 2 or later (the
@@ -39,6 +40,8 @@
 #include "proc.h"
 #include "arena.h"
 
+// GP: clean (only 1 M() macro)
+
 // the unsigned long is split into two parts: a masked hash in the lower bits, and 
 // age in the upper;
 // HASH_CODE_BITS determines the max width of the hash code
@@ -68,14 +71,14 @@ void HashTable::initialize()
     itemsCount = 0;
 }
 
-// changing buckets(logSize) to buckets(logSize_)
-
 HashTable::HashTable(Processor *proc_, Arena *arena_, int logSize_)
 : proc( proc_ ), theArena( arena_ ), logSize( logSize_ ), buckets( logSize_ ),
   _theEmptyKey(NULL)
 {
     _theEmptyKey = new Str;
-    initialize();
+    //    initialize();
+    visitedBuckets = 0;
+    itemsCount = -1; // not initialized yet
 }
 
 void HashTable::destroy()
@@ -113,6 +116,7 @@ inline oolong HashTable::codeToIndex(oolong code) const
 
 Bool HashTable::lookupOrPreceding(const Str& key, oolong hashed, HashItem *&p) const
 {
+    assert(itemsCount != -1);     // assert hash table initialized
     for ( p = buckets[hashMask(hashed, logSize)]; p; p = p -> next )
     {
         if (p -> key == key)
@@ -126,6 +130,7 @@ Bool HashTable::lookupOrPreceding(const Str& key, oolong hashed, HashItem *&p) c
 
 eFlag HashTable::insert(const Str& key, HashId& id, const void *data /* = NULL */)
 {
+    assert(itemsCount != -1);     // assert hash table initialized
     oolong hashed = hash( key );
     HashItem *p, *q;
     // try to find our item, or at least its predecessor
@@ -138,7 +143,7 @@ eFlag HashTable::insert(const Str& key, HashId& id, const void *data /* = NULL *
         ++itemsCount;
         q = new( theArena )
             HashItem( key, hashed, data, p ? p -> age + 1 : 0, theArena );
-        M( proc -> situation, q );
+        M( proc -> situation, q );  // GP: OK (only fails if nothing to dealloc)
         if (p)
             p = p -> next = q;
         else
@@ -153,6 +158,7 @@ eFlag HashTable::insert(const Str& key, HashId& id, const void *data /* = NULL *
 
 HashId HashTable::lookup(const Str& key, const void **data /* = NULL */) const
 {
+    assert(itemsCount != -1);     // assert hash table initialized
     oolong hashed = hash( key );
     HashItem *p;
     if (!lookupOrPreceding( key, hashed, p ))
@@ -168,25 +174,28 @@ HashId HashTable::lookup(const Str& key, const void **data /* = NULL */) const
 { if (TAIL) TAIL = TAIL -> next = NEWPTR;\
 else { TAIL = buckets[ROOT_NDX] = NEWPTR; visitedBuckets++; }}
 
+// this function fixed by Tom Moog
+
 HashItem *HashTable::expandWatching( oolong hashed )
 {
+    assert(itemsCount != -1);     // assert hash table initialized
     oolong i, oldBucketCount = buckets.number();
     for (i = 0; i < oldBucketCount; i++)
         buckets.append(NULL);
     oolong distinguish = 1L << logSize;
 
     HashItem *p,
-        *upperTail = NULL,
-        *lowerTail = NULL,
+        *upperTail,
+        *lowerTail,
         *retval = NULL;
 
     visitedBuckets = 0;
 
-    for (i = 0; i < oldBucketCount; i++)
+    for (i = 0; i < oldBucketCount; i++)    
     {
+        upperTail = lowerTail = NULL;
         for (p = buckets[i]; p; p = p -> next)
         {
-            upperTail = lowerTail = NULL;
             if (p -> code & distinguish)
                 chain(p, upperTail, i + oldBucketCount)
             else
@@ -194,6 +203,12 @@ HashItem *HashTable::expandWatching( oolong hashed )
         };
         if (buckets[i])
             ++visitedBuckets;
+        if (lowerTail)
+            lowerTail -> next = NULL;
+        else
+            buckets[i] = NULL;
+        if (upperTail)
+            upperTail -> next = NULL;
         // do the watching
         if ( codeToIndex(hashed) == i )
             retval = (hashed & distinguish) ? upperTail : lowerTail;
@@ -206,6 +221,7 @@ HashItem *HashTable::expandWatching( oolong hashed )
 
 const Str& HashTable::getKey(HashId id) const
 {
+  assert(itemsCount != -1);     // assert hash table initialized
   if (id == UNDEF_PHRASE) 
     {
       return *_theEmptyKey; /* __PH__ */
