@@ -37,22 +37,12 @@
 #if !defined(Utf8HIncl)
 #define Utf8HIncl
 
+// GP: clean
+
 #include "base.h"
 
 #define SMALL_BUFFER_SIZE 32
 
-enum Encoding
-{
-    ENC_UTF8,
-    ENC_UTF16,
-    ENC_ASCII,
-    ENC_8859_1,
-    ENC_8859_2,
-    ENC_1250,
-    ENC_EUCJP,
-    ENC_SJIS    
-};
-
 extern  int     utf8SingleCharLength(const char* text);
 
 extern  unsigned long 
@@ -60,12 +50,17 @@ extern  unsigned long
 
 extern  int     utf8GetChar(char *dest, const char *src);
 
+/* NO MORE USED:
 extern  Bool    utf8CanRecodeTo(const char *destEncoding);
 
 extern  int     utf8Recode(char* dest, const char* src, Encoding enc);
+*/
 
 extern  Str     utf8xfrm(const Str &src);
 
+extern  int     utf8FromCharCode(char *dest, unsigned long code);
+
+
 extern	Bool	utf8IsDigit(unsigned long c);
 extern	Bool	utf8IsBaseChar(unsigned long c);
 extern	Bool	utf8IsLetter(unsigned long c);
